@@ -14,12 +14,15 @@ from .const import (
     CURRENT_HVAC_OFF,
     HVAC_MODE_HEAT,
     HVAC_MODE_OFF,
+    HVAC_MODE_AUTO,
     PRESET_FOLLOW_SCHEDULE,
     PRESET_OFF,
     PRESET_PERMANENT_HOLD,
     SUPPORT_PRESET_MODE,
     SUPPORT_TARGET_TEMPERATURE,
     TEMP_CELSIUS,
+    SUPPORT_OPEN,
+    SUPPORT_CLOSE,
     SUPPORT_SET_POSITION, STATE_UNKNOWN
 )
 from .encryptor import IT600Encryptor
@@ -209,7 +212,7 @@ class IT600Gateway:
                         is_opening=None if set_position is None else current_position < set_position,
                         is_closing=None if set_position is None else current_position > set_position,
                         is_closed=True if current_position == 0 else False,
-                        supported_features=SUPPORT_SET_POSITION,
+                        supported_features=SUPPORT_OPEN | SUPPORT_CLOSE | SUPPORT_SET_POSITION,
                         device_class=None,
                         data=device_status["data"],
                         manufacturer=device_status.get("sBasicS", {}).get("ManufactureName", "SALUS"),
@@ -309,12 +312,14 @@ class IT600Gateway:
                     if temperature is None:
                         continue
 
+                    unique_id = unique_id + "_temp"  # Some sensors also measure temperature besides their primary function (eg. SW600)
+
                     model: Optional[str] = device_status.get("DeviceL", {}).get("ModelIdentifier_i", None)
 
                     device = SensorDevice(
                         available=True if device_status.get("sZDOInfo", {}).get("OnlineStatus_i", 1) == 1 else False,
                         name=json.loads(device_status.get("sZDO", {}).get("DeviceName", '{"deviceName": "Unknown"}'))["deviceName"],
-                        unique_id=device_status["data"]["UniID"],
+                        unique_id=unique_id,
                         state=(temperature / 100),
                         unit_of_measurement=TEMP_CELSIUS,
                         device_class="temperature",
@@ -354,9 +359,6 @@ class IT600Gateway:
                     continue
 
                 try:
-                    if device_status.get("sTempS", None) is not None:
-                        continue  # Skip temperature sensors (eg. PS600 pipe sensor)
-
                     is_on: Optional[bool] = device_status.get("sIASZS", {}).get("ErrorIASZSAlarmed1", None)
 
                     if is_on is None:
@@ -364,6 +366,9 @@ class IT600Gateway:
 
                     model: Optional[str] = device_status.get("DeviceL", {}).get("ModelIdentifier_i", None)
 
+                    if model == "SB600":
+                        continue  # Skip button
+
                     device = BinarySensorDevice(
                         available=True if device_status.get("sZDOInfo", {}).get("OnlineStatus_i", 1) == 1 else False,
                         name=json.loads(device_status.get("sZDO", {}).get("DeviceName", '{"deviceName": "Unknown"}'))["deviceName"],
@@ -417,14 +422,14 @@ class IT600Gateway:
                     device = ClimateDevice(
                         available=True if device_status.get("sZDOInfo", {}).get("OnlineStatus_i", 1) == 1 else False,
                         name=json.loads(device_status.get("sZDO", {}).get("DeviceName", '{"deviceName": "Unknown"}'))["deviceName"],
-                        unique_id=device_status["data"]["UniID"],
+                        unique_id=unique_id,
                         temperature_unit=TEMP_CELSIUS,  # API always reports temperature as celsius
                         precision=0.5,
                         current_temperature=th["LocalTemperature_x100"] / 100,
                         target_temperature=th["HeatingSetpoint_x100"] / 100,
                         max_temp=th.get("MaxHeatSetpoint_x100", 3500) / 100,
                         min_temp=th.get("MinHeatSetpoint_x100", 500) / 100,
-                        hvac_mode=HVAC_MODE_OFF if th["HoldType"] == 7 else HVAC_MODE_HEAT,
+                        hvac_mode=HVAC_MODE_OFF if th["HoldType"] == 7 else HVAC_MODE_HEAT if th["HoldType"] == 2 else HVAC_MODE_AUTO,
                         hvac_action=CURRENT_HVAC_OFF if th["HoldType"] == 7 else CURRENT_HVAC_IDLE if th["RunningState"] % 2 == 0 else CURRENT_HVAC_HEAT,  # RunningState 0 or 128 => idle, 1 or 129 => heating
                         hvac_modes=[HVAC_MODE_OFF, HVAC_MODE_HEAT],
                         preset_mode=PRESET_OFF if th["HoldType"] == 7 else PRESET_PERMANENT_HOLD if th["HoldType"] == 2 else PRESET_FOLLOW_SCHEDULE,
@@ -570,6 +575,54 @@ class IT600Gateway:
             },
         )
 
+    async def open_cover(self, device_id: str) -> None:
+        """Public method to open the specified cover device."""
+
+        device = self.get_cover_device(device_id)
+
+        if device is None:
+            _LOGGER.error("Cannot turn on: cover device not found with the specified id: %s", device_id)
+            return
+
+        await self._make_encrypted_request(
+            "write",
+            {
+                "requestAttr": "write",
+                "id": [
+                    {
+                        "data": device.data,
+                        "sLevelS": {
+                            "SetMoveToLevel": f"{format(100, '02x')}FFFF"
+                        },
+                    }
+                ],
+            },
+        )
+
+    async def close_cover(self, device_id: str) -> None:
+        """Public method to close the specified cover device."""
+
+        device = self.get_cover_device(device_id)
+
+        if device is None:
+            _LOGGER.error("Cannot turn on: cover device not found with the specified id: %s", device_id)
+            return
+
+        await self._make_encrypted_request(
+            "write",
+            {
+                "requestAttr": "write",
+                "id": [
+                    {
+                        "data": device.data,
+                        "sLevelS": {
+                            "SetMoveToLevel": f"{format(0, '02x')}FFFF"
+                        },
+                    }
+                ],
+            },
+        )
+
     async def turn_on_switch_device(self, device_id: str) -> None:
         """Public method to turn on the specified switch device."""
 
